@@ -88,7 +88,7 @@ colorPalette <- function(name, n = NULL) {
       "blackwhite" = c("black", "white"),
       "bell" = c("#000000", "#ff0000", "#ffcc00"),
       "boogy1" = c("#a2a07a", "#c49700", "#b4b9cc", "#c0c1b1"),
-      "boogy2" = c("#204b9a", "#f1e60e", "#ffffff", "#e5181d", "1d1d1b"),
+      "boogy2" = c("#204b9a", "#f1e60e", "#ffffff", "#e5181d", "#1d1d1b"),
       "boogy3" = c("#e9e489", "#995c25", "#5eb9f0", "#68b95d", "#69241f"),
       "dark1" = c("#161616", "#346751", "#C84B31", "#ECDBBA"),
       "dark2" = c("#1B262C", "#0F4C75", "#3282B8", "#BBE1FA"),
@@ -102,7 +102,7 @@ colorPalette <- function(name, n = NULL) {
       "klimt" = c("#847049", "#ba9d3e", "#29241f", "#a787b0", "#cd5627", "#7ea36e"),
       "kpd" = c("#c42f32", "#315b99", "#354741"),
       "lava" = c("#f59907", "#a42300", "#482a22", "#050000", "#6b0800"),
-      "mixer1" = c("#fa9f29", "#15cab1", "0a633d", "2f3030"),
+      "mixer1" = c("#fa9f29", "#15cab1", "#0a633d", "#2f3030"),
       "mixer2" = c("#a3a948", "#edb92e", "#f85931", "#ce1836", "#009989"),
       "mixer3" = c("#aacad5", "#c9e0e6", "#e0e9ee", "#dccda4", "#99886e"),
       "mixer4" = c("#20663F", "#259959", "#ABD406", "#FFD412", "#FF821C"),
